import React, { useState } from 'react';
import { BrowserRouter as Router, Routes, Route, Navigate, useNavigate } from 'react-router-dom';
import { Layout, Menu, ConfigProvider } from 'antd';
import { 
  DashboardOutlined, 
  PhoneOutlined, 
  FileTextOutlined, 
  CalendarOutlined 
} from '@ant-design/icons';
import zhCN from 'antd/locale/zh_CN';
import 'antd/dist/reset.css';
import './App.css';

// 导入页面组件
import Dashboard from './pages/Dashboard';
import CallDetail from './pages/Calls/CallDetail';
import DocumentDetail from './pages/Documents/DocumentDetail';
import AppointmentDetail from './pages/Appointments/AppointmentDetail';

const { Header, Sider, Content } = Layout;

const AppContent: React.FC = () => {
  const navigate = useNavigate();
  const [selectedKey, setSelectedKey] = useState('1');

  const handleMenuClick = (e: any) => {
    setSelectedKey(e.key);
    switch (e.key) {
      case '1':
        navigate('/dashboard');
        break;
      case '2':
        navigate('/calls/1');
        break;
      case '3':
        navigate('/documents/1');
        break;
      case '4':
        navigate('/appointments/1');
        break;
    }
  };

  return (
    <Layout style={{ minHeight: '100vh' }}>
      <Sider
        breakpoint="lg"
        collapsedWidth="0"
        style={{
          background: '#001529',
        }}
      >
        <div style={{ 
          height: 32, 
          margin: 16, 
          background: 'rgba(255,255,255,.2)',
          borderRadius: 4,
          display: 'flex',
          alignItems: 'center',
          justifyContent: 'center',
          color: 'white',
          fontWeight: 'bold'
        }}>
          Twilio管理系统
        </div>
        <Menu
          theme="dark"
          mode="inline"
          selectedKeys={[selectedKey]}
          onClick={handleMenuClick}
          items={[
            {
              key: '1',
              icon: <DashboardOutlined />,
              label: '仪表板',
            },
            {
              key: '2',
              icon: <PhoneOutlined />,
              label: '通话管理',
            },
            {
              key: '3',
              icon: <FileTextOutlined />,
              label: '文档翻译',
            },
            {
              key: '4',
              icon: <CalendarOutlined />,
              label: '预约管理',
            },
          ]}
        />
      </Sider>
      <Layout>
        <Header style={{ 
          padding: 0, 
          background: '#fff',
          boxShadow: '0 1px 4px rgba(0,21,41,.08)'
        }}>
          <div style={{ 
            padding: '0 24px',
            fontSize: '18px',
            fontWeight: 'bold'
          }}>
            Twilio翻译服务管理后台
          </div>
        </Header>
        <Content style={{ margin: '24px 16px 0', overflow: 'initial' }}>
          <div style={{ 
            padding: 24, 
            background: '#fff', 
            minHeight: 360,
            borderRadius: 8
          }}>
            <Routes>
              <Route path="/" element={<Navigate to="/dashboard" replace />} />
              <Route path="/dashboard" element={<Dashboard />} />
              <Route path="/calls/:id" element={<CallDetail />} />
              <Route path="/documents/:id" element={<DocumentDetail />} />
              <Route path="/appointments/:id" element={<AppointmentDetail />} />
            </Routes>
          </div>
        </Content>
      </Layout>
    </Layout>
  );
};

const App: React.FC = () => {
  return (
    <ConfigProvider locale={zhCN}>
      <Router>
        <AppContent />
      </Router>
    </ConfigProvider>
  );
};

export default App; 