// 通话相关类型
export interface TranslationCall {
  id: string;
  userId: string;
  callId: string;
  clientName: string;
  clientPhone: string;
  type: 'human' | 'ai';
  status: 'pending' | 'active' | 'completed' | 'cancelled' | 'refunded';
  sourceLanguage: string;
  targetLanguage: string;
  startTime: string;
  endTime?: string;
  duration?: number;
  cost: number;
  rating?: number;
  feedback?: string;
  translatorId?: string;
  translatorName?: string;
  translatorPhone?: string;
  recordingUrl?: string;
  transcription?: string;
  translation?: string;
  // 管理员相关字段
  adminNotes?: string;
  paymentStatus: 'pending' | 'paid' | 'refunded' | 'failed';
  refundAmount: number;
  qualityScore: number;
  issues: string[];
  createdAt?: string;
  updatedAt?: string;
}

// 文档翻译相关类型
export interface DocumentTranslation {
  id: string;
  userId: string;
  fileName: string;
  originalSize: number;
  fileUrl: string;
  translatedFileUrl?: string;
  sourceLanguage: string;
  targetLanguage: string;
  status: 'pending' | 'in_progress' | 'completed' | 'cancelled' | 'failed';
  progress: number;
  quality: 'basic' | 'professional' | 'premium';
  urgency: 'normal' | 'urgent' | 'emergency';
  estimatedTime: number;
  actualTime?: number;
  cost: number;
  translatorId?: string;
  translatorName?: string;
  rating?: number;
  feedback?: string;
  createdAt: string;
  completedAt?: string;
  // 管理员相关字段
  adminNotes?: string;
  paymentStatus: 'pending' | 'paid' | 'refunded' | 'failed';
  refundAmount: number;
  qualityScore: number;
  issues: string[];
  retranslationCount?: number;
  clientName?: string;
  clientEmail?: string;
  clientPhone?: string;
  updatedAt?: string;
}

// 预约相关类型
export interface Appointment {
  id: string;
  userId: string;
  translatorId: string;
  title: string;
  description: string;
  type: string;
  sourceLanguage: string;
  targetLanguage: string;
  startTime: string;
  endTime: string;
  status: string;
  cost: number;
  meetingUrl?: string;
  notes?: string;
  reminderSent: boolean;
  createdAt: string;
  updatedAt?: string;
  // 管理员相关字段
  clientName: string;
  clientEmail: string;
  clientPhone: string;
  translatorName: string;
  translatorEmail: string;
  translatorPhone: string;
  adminNotes?: string;
  paymentStatus: string;
  refundAmount: number;
  qualityScore: number;
  issues: string[];
  rating?: number;
  feedback?: string;
  location?: string;
  urgency: string;
}

// 用户类型
export interface User {
  id: string;
  name: string;
  email: string;
  phone?: string;
  role: 'client' | 'translator' | 'admin';
  status: 'active' | 'inactive' | 'suspended';
  createdAt: string;
  updatedAt?: string;
}

// 译员类型
export interface Translator {
  id: string;
  name: string;
  email: string;
  phone: string;
  languages: string[];
  specializations: string[];
  rating: number;
  hourlyRate: number;
  status: 'available' | 'busy' | 'offline';
  totalJobs: number;
  successRate: number;
  createdAt: string;
}

// API响应类型
export interface ApiResponse<T = any> {
  success: boolean;
  data?: T;
  message?: string;
  error?: string;
}

// 分页类型
export interface PaginationParams {
  page: number;
  pageSize: number;
  total?: number;
}

// 搜索参数类型
export interface SearchParams {
  keyword?: string;
  status?: string;
  dateRange?: [string, string];
  [key: string]: any;
} 